@@ -4,8 +4,17 @@
 import sys
 
 
+class ThumbError(Exception):
+    pass
+
+
+class ThumbVideoError(ThumbError):
+    pass
+
+
 class TelegramUploadError(Exception):
     body = ''
+    error_code = 1
 
     def __init__(self, extra_body=''):
         self.extra_body = extra_body
@@ -19,10 +28,19 @@ class TelegramUploadError(Exception):
         return msg
 
 
+class TelegramInvalidFile(TelegramUploadError):
+    error_code = 3
+
+
+class TelegramUploadNoSpaceError(TelegramUploadError):
+    error_code = 28
+
+
 def catch(fn):
     def wrap(*args, **kwargs):
         try:
             fn(*args, **kwargs)
         except TelegramUploadError as e:
             sys.stderr.write('[Error] telegram-upload Exception:\n{}\n'.format(e))
+            exit(e.error_code)
     return wrap
